@@ -29,7 +29,6 @@ __copyright__ = "Copyright (c) 2004-2009 Sun Microsystems Inc." \
                 "Copyright (c) 2012 Igalia, S.L."
 __license__   = "LGPL"
 
-import importlib
 import os
 import pyatspi
 import re
@@ -263,7 +262,6 @@ def _processKeyboardEvent(event):
             _createOrcaXmodmap()
             _restoreOrcaKeys = False
     elif not keyboardEvent.isModifierKey():
-        _orcaModifierPressed = False
         orca_state.bypassNextCommand = False
  
     return isOrcaModifier or orca_state.learnModeEnabled
@@ -324,7 +322,7 @@ def _setCapsLockAsOrcaModifier(enable):
         r'^\s*action\s*=\s*LockMods\s*\(\s*modifiers\s*=\s*Lock\s*\)\s*;\s*$', re.I)
     normalCapsLine = '        action= LockMods(modifiers=Lock);'
     capsModLine =    '        action= SetMods(modifiers=Lock,clearLocks);'
-    lines = _originalXmodmap.split('\n')
+    lines = _originalXmodmap.decode('UTF-8').split('\n')
     foundCapsInterpretSection = False
     for i in range(len(lines)):
         line = lines[i]
@@ -335,12 +333,12 @@ def _setCapsLockAsOrcaModifier(enable):
             if enable:
                 if normalCapsLineProg.match(line):
                     lines[i] = capsModLine
-                    _setXmodmap('\n'.join(lines))
+                    _setXmodmap(bytes('\n'.join(lines), 'UTF-8'))
                     return
             else:
                 if capsModLineProg.match(line):
                     lines[i] = normalCapsLine
-                    _setXmodmap('\n'.join(lines))
+                    _setXmodmap(bytes('\n'.join(lines), 'UTF-8'))
                     return
             if line.find('}'):
                 # Failed to find the line we need to change
@@ -486,7 +484,10 @@ def showAppPreferencesGUI(script=None, inputEvent=None):
     """
 
     try:
-        module = importlib.import_module('.app_gui_prefs', 'orca')
+        module = __import__(settings.appGuiPreferencesModule,
+                            globals(),
+                            locals(),
+                            [''])
         module.showPreferencesUI()
     except:
         debug.printException(debug.LEVEL_SEVERE)
@@ -501,7 +502,10 @@ def showPreferencesGUI(script=None, inputEvent=None):
     """
 
     try:
-        module = importlib.import_module('.orca_gui_prefs', 'orca')
+        module = __import__(settings.guiPreferencesModule,
+                            globals(),
+                            locals(),
+                            [''])
         module.showPreferencesUI()
     except:
         debug.printException(debug.LEVEL_SEVERE)
@@ -515,7 +519,10 @@ def showMainWindowGUI(script=None, inputEvent=None):
     """
 
     try:
-        module = importlib.import_module('.orca_gui_main', 'orca')
+        module = __import__(settings.mainWindowModule,
+                            globals(),
+                            locals(),
+                            [''])
         if settings.showMainWindow or settings.overrideDisabledMainWindow:
             module.showMainUI()
         else:
@@ -717,7 +724,10 @@ def quitOrca(script=None, inputEvent=None):
         shutdown()
     else:
         try:
-            module = importlib.import_module('.orca_gui_quit', 'orca')
+            module = __import__(settings.quitModule,
+                                globals(),
+                                locals(),
+                                [''])
             module.showQuitUI()
         except:
             debug.printException(debug.LEVEL_SEVERE)
@@ -731,7 +741,10 @@ def showFindGUI(script=None, inputEvent=None):
     """
 
     try:
-        module = importlib.import_module('.orca_gui_find', 'orca')
+        module = __import__(settings.findModule,
+                            globals(),
+                            locals(),
+                            [''])
         module.showFindUI()
     except:
         debug.printException(debug.LEVEL_SEVERE)
@@ -743,7 +756,10 @@ def showSplashGUI(script=None, inputEvent=None):
     """
 
     try:
-        module = importlib.import_module('.orca_gui_splash', 'orca')
+        module = __import__(settings.splashModule,
+                            globals(),
+                            locals(),
+                            [''])
         if _settingsManager.getSetting("showSplashWindow"):
             module.showSplashUI()
         else:
