@@ -33,7 +33,7 @@ ngettext = gettext.ngettext
 
 # Tell gettext where to find localized strings.
 #
-localedir = os.path.join ("/home/jd/checkout/gnome/orca/bld", "share", "locale")
+localedir = os.path.join ("/home/jd/orca-python3/bld", "share", "locale")
 gettext.bindtextdomain ("orca", localedir)
 gettext.textdomain("orca")
 
