@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "3.7.0.5"
+version     = "3.7.0.90"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/home/jd/checkout/gnome/orca/bld"
+prefix      = "/home/jd/orca-python3/bld"
 
 # The package name (should be "orca").
 #
@@ -44,4 +44,4 @@ datadirname = "share"
 
 # The directory where we could find liblouis translation tables.
 #
-tablesdir = ""
+tablesdir = "/usr/share/liblouis/tables"
